:py:mod:`icclim._core.model`
============================

.. py:module:: icclim._core.model

.. autoapi-nested-parse::

   Contain the dataclasses, TypedDicts and basic registries of icclim.



Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   cf_calendar/index.rst
   global_metadata/index.rst
   icclim_types/index.rst
   in_file_dictionary/index.rst
   index_config/index.rst
   index_group/index.rst
   indicator/index.rst
   logical_link/index.rst
   netcdf_version/index.rst
   operator/index.rst
   quantile_interpolation/index.rst
   registry/index.rst
   standard_index/index.rst
   standard_variable/index.rst
   threshold/index.rst
